@@ -18,8 +18,8 @@ checkScores3L<-function(this.response, this.response2=NA, this.response3=NA, thi
     return(NA)
   }else{
     if(length(this.response)!=5 && length(this.response)!=1){
+      warning("Invalid EQ-5D-5L responses-check the responses to each question \n")
       return(-1)
-      stop("Invalid EQ-5D-5L responses-check the responses to each question \n")
     }else{
       if(length(this.response)==5){#first value a vector
         this.score <- paste(this.response,collapse = "")
@@ -31,24 +31,27 @@ checkScores3L<-function(this.response, this.response2=NA, this.response3=NA, thi
             responses<-convertNumberToIndividualDigits(this.score)
           }else{
             responses<-NA  
-            #message("Can not convert to individual digits \n")
+            #warning("Can not convert to individual digits \n")
           }
         }
       }
     }
   }
   if(!all(responses%in% 1:3)){
+    warning("Responses not valid for EQ-5D-3L scores \n")
     return(-2)
-    stop("Responses not valid for EQ-5D-3L scores \n")
+    
   }else{
     this.score<-as.numeric(this.score)
     if(this.score<11111 || this.score>33333){
       if(this.score<0 || this.score>33333){
+        warning("Responses not valid for EQ-5D-5L scores \n")
         return(-3)
-        stop("Responses not valid for EQ-5D-5L scores \n")
+        
       }else{
+        warning("Responses not valid for EQ-5D-5L scores or some missing \n")
         return(NA)
-        stop("Responses not valid for EQ-5D-5L scores or some missing \n")
+        
       }
     }else{
       return(responses)
@@ -75,8 +78,9 @@ checkScores5L<-function(this.response, this.response2=NA, this.response3=NA, thi
     return(NA)
   }else{
     if(length(this.response)!=5 && length(this.response)!=1){
+      warning("Invalid EQ-5D-5L responses-check the responses to each question \n")
       return(-1)
-      stop("Invalid EQ-5D-5L responses-check the responses to each question \n")
+      
     }else{
       if(length(this.response)==5){#first value a vector
         this.score <- paste(this.response,collapse = "")
@@ -87,8 +91,9 @@ checkScores5L<-function(this.response, this.response2=NA, this.response3=NA, thi
           if(sum(convertNumberToIndividualDigits(this.score))!=-1){
             responses<-convertNumberToIndividualDigits(this.score)
           }else{
+            warning("Can not convert to individual digits \n")
             return(-4)
-            stop("Can not convert to individual digits \n")
+            
           }
         }
       }
@@ -96,21 +101,25 @@ checkScores5L<-function(this.response, this.response2=NA, this.response3=NA, thi
   }
   if(!all(responses%in% 1:5)){
     if(sum(is.na(responses)>0)){
+      warning("Responses not valid for EQ-5D-5L scores \n")
       return(NA)
-      stop("Responses not valid for EQ-5D-5L scores \n")
+      
     }else{
+      warning("Responses not valid for EQ-5D-5L scores \n")
       return(-2)
-      stop("Responses not valid for EQ-5D-5L scores \n")
+      
     }
   }else{
     this.score<-as.numeric(this.score)
     if(this.score<11111 || this.score>55555){
       if(this.score<0 || this.score>55555){
-         return(-3)
-         stop("Responses not valid for EQ-5D-5L scores \n")
+        warning("Responses not valid for EQ-5D-5L scores \n")
+        return(-3)
+        
       }else{
+        warning("Responses not valid for EQ-5D-5L scores or some missing \n")
         return(NA)
-        stop("Responses not valid for EQ-5D-5L scores or some missing \n")
+        
       }
     }else{
       return(responses)
@@ -134,8 +143,9 @@ valueEQ5D5LIndscores<-function(country,this.response,this.response2=NA, this.res
   countrylist=c("Canada","China","England" ,"Germany","Hong_Kong","Indonesia","Ireland",
                 "Japan","Korea","Malaysia","Netherlands","Poland","Portugal","Spain","Taiwan","Thailand","Uruguay")
   if(replaceSpaceUnderscore(country)==-1){
+    warning("Country name empty")
     return(-1)
-    stop("Country name empty")
+    
   }else{
     country<-replaceSpaceUnderscore(country)
   }
@@ -145,8 +155,9 @@ valueEQ5D5LIndscores<-function(country,this.response,this.response2=NA, this.res
       return(NA)
     }else{
       if(sum(scores)<0){
+        warning("EQ-5D-5L scores are not valid \n")
         return(-2)
-        stop("EQ-5D-5L scores are not valid \n")
+        
       }else{
         eq5d.valueset=EQ5D5L_tariffs.df
         names(scores)<-c("MO","SC","UA","PD","AD")
@@ -198,8 +209,9 @@ valueEQ5D5LIndscores<-function(country,this.response,this.response2=NA, this.res
     }
     return(values.state)
   }else{
+    warning("No tariffs found for the country you specified for EQ-5D-5L. Please try later \n")
     return(-3)
-    stop("No tariffs found for the country you specified for EQ-5D-5L. Please try later \n")
+    
   }
 }
   
@@ -227,8 +239,9 @@ valueEQ5D5L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country="England",groupby
     working.data=subsetGenderAgeToGroup(eq5dresponse.data,groupby,agelimit)
     scores=c()
     if(nrow(working.data)<1 && working.data<0){
+      warning("No entries with the given criteria - Please check the contents or the criteria \n")
       return(-1)
-      stop("No entries with the given criteria - Please check the contents or the criteria \n")
+      
     }else{
       for(j in 1:nrow(working.data)){
         res1=working.data[j,mo]
@@ -240,8 +253,9 @@ valueEQ5D5L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country="England",groupby
         if(this.score>=0){
           scores=c(scores,this.score)
         }else{
+          warning("EQ-5D-5L responses not valid - 5L scores can not be valued \n")
           return(-2)
-          stop("EQ-5D-5L responses not valid - 5L scores can not be valued \n")
+          
         }
       }
       names(scores)<-"EQ-5D-5Lscores"
@@ -272,8 +286,9 @@ valueEQ5D5L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country="England",groupby
       return(results)
     }
   }else{# if the eq 5d column names do not match
+    warning("EQ-5D column names do not match \n")
     return(-3)
-    stop("EQ-5D column names do not match \n")
+    
     
   }
 }
@@ -302,8 +317,8 @@ valueEQ5D3LIndscores<-function(country,method,this.response,this.response2=NA, t
   australia.impalusibleordering.scores<-c(33132, 12133,13133, 22133,23133,32133,33133,12233,13233,22233,23233,32233,33233,33232,33323,13332,13333,23332,23333,32333,33332,33333)
   
   if(replaceSpaceUnderscore(country)==-1){
+    warning("Country name empty")
     return(-1)
-    stop("Country name empty")
   }else{
     country<-replaceSpaceUnderscore(country)
   }
@@ -313,7 +328,7 @@ valueEQ5D3LIndscores<-function(country,method,this.response,this.response2=NA, t
       return(NA)
     }else{
       if(sum(scores)<0){
-        message("EQ-5D-3L scores are not valid \n")
+        warning("EQ-5D-3L scores are not valid \n")
         return(-3)
       }else{
         if(method=="TTO" && country%in%TTO_countrylist){
@@ -322,7 +337,7 @@ valueEQ5D3LIndscores<-function(country,method,this.response,this.response2=NA, t
           if(method=="VAS"&& country%in%VAS_countrylist){
             eq5d.valueset=EQ5D3L_tariffs_VAS.df
           }else{
-            message("No tariff found \n")
+            warning("No tariff found \n")
             return(-4)
           }
         }
@@ -490,7 +505,6 @@ valueEQ5D3LIndscores<-function(country,method,this.response,this.response2=NA, t
               if( !is.na(eq5d.valueset[rownum_Nos3Sq,country]))
                 Nos3Sq.value<-(length(which(scores==3)))^2*eq5d.valueset[rownum_Nos3Sq,country]
             }
-            
             if( scores[["MO"]]==3 & scores[["SC"]]==3 & sum(is.na(rownum_MO3SC3)==0)){
               if( !is.na(eq5d.valueset[rownum_MO3SC3,country]))
                 MO3SC3.value<-eq5d.valueset[rownum_MO3SC3,country]
@@ -554,16 +568,16 @@ valueEQ5D3LIndscores<-function(country,method,this.response,this.response2=NA, t
               values.state<-sum(values,na.rm =TRUE)
             }
           }else{
+            warning("No country tariffs \n")
             return(-5)
-            stop("No country tariffs \n")
           }
         }
       }
     }
     return(values.state)
   }else{
+    warning("No country tariffs found for the country you specified for EQ-5D-3L. Please try later \n")
     return(-2)
-    stop("No country tariffs found for the country you specified for EQ-5D-3L. Please try later \n")
   }
 }
 ###########################################################################################################
@@ -589,8 +603,8 @@ valueEQ5D3L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country,method,groupby,ag
   if(all(ans.eq5d.colnames==0)){# if the eq5d column names match
     working.data=subsetGenderAgeToGroup(eq5dresponse.data,groupby,agelimit)
     if(nrow(working.data)<1 && working.data<0){
+      warning("No entries with the given criteria - Please check the contents or the criteria \n")
       return(-1)
-      stop("No entries with the given criteria - Please check the contents or the criteria \n")
     }else{
       scores=c()
       for(j in 1:nrow(working.data)){
@@ -603,8 +617,8 @@ valueEQ5D3L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country,method,groupby,ag
         if(this.score!=-1){
           scores=c(scores,this.score)
         }else{
+          warning("Responses not valid -3L scores can not be valued \n")
           return(-2)
-          stop("Responses not valid -3L scores can not be valued \n")
         }
       }
       names(scores)<-"EQ-5D-3Lscores"
@@ -635,9 +649,8 @@ valueEQ5D3L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country,method,groupby,ag
       return(results)
     }
   }else{# if the eq 5d column names do not match
-     return(-3)
-    stop("EQ-5D column names do not match \n")
-    
+    warning("EQ-5D column names do not match \n")
+    return(-3)
   }
 }
 ###########################################################################################################
@@ -658,8 +671,8 @@ valueEQ5D3L<-function(eq5dresponse.data,mo,sc,ua,pd,ad,country,method,groupby,ag
 eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.response2=NA,this.response3=NA,this.response4=NA,this.response5=NA) {
   countrylist=c("Denmark" ,"France","Germany","Japan", "Netherlands","Spain","Thailand","UK","USA","Zimbabwe")
   if(replaceSpaceUnderscore(country)==-1){
+    warning("Country name empty")
     return(-1)
-    stop("Country name empty")
   }else{
     country<-replaceSpaceUnderscore(country)
   }
@@ -671,8 +684,8 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
       return(values.state)
     }else{# check first value should be a vector containiing responses or a 5digit number
       if(length(this.response)!=5 && length(this.response)!=1){
-         return(-3)
-         stop("Invalid EQ-5D-5L responses-check the responses to each question \n")
+         warning("Invalid EQ-5D-5L responses-check the responses to each question \n")
+        return(-3)
       }else{ #first value a vector or a 5 figit number
         if(length(this.response)==5){#first value a vector
           this.score.5L <- paste(this.response,collapse = "")
@@ -687,8 +700,8 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
                   if(any(responses<=5)){
                     this.score.5L <- paste(responses,collapse = "")#all valid and generate the score
                   }else{#error values
+                    warning("Invalid EQ-5D-5L responses-check the responses to each question \n")
                     return(-5)
-                    stop("Invalid EQ-5D-5L responses-check the responses to each question \n")
                   }
                 }else{
                   #missing values
@@ -697,8 +710,8 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
                   return(values.state)
                 }
               }else{
+                warning("Invalid EQ-5D-5L responses-check the responses to each question \n")
                 return(-4)    
-                stop("Invalid EQ-5D-5L responses-check the responses to each question \n")
               }
             }
           }
@@ -706,8 +719,8 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
       }
     }
     if(this.score.5L<11111 || this.score.5L>55555){
-       return(-6)
-       stop("Invalid EQ-5D-5L responses -less than 11111 or more than 55555 \n")
+       warning("Invalid EQ-5D-5L responses -less than 11111 or more than 55555 \n")
+      return(-6)
     }else{
       ## create a vector of all possible 3L index values (length == 3^5)
       index_3L <- numeric(243)
@@ -746,8 +759,8 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
         rows_m=nrow(m)
         cols_m=ncol(m)
         if(rows_m!=3125 || cols_m!=243){
+          warning("Error in number of cols or rows of probability matrix \n")
           return(-7)
-          stop("Error in number of cols or rows of probability matrix \n")
         }
         ## multiply each row of 't(m)' with 'index_3L'
         m_prod <- t(t(m) * index_3L)
@@ -765,17 +778,15 @@ eq5dmap5Lto3LIndscores<-function(country="UK",method="CW",this.response,this.res
           return(m_sums[this_score])
         }
       }else{
+        warning("The specified method is not implemented \n")
         return(-8)
-        stop("The specified method is not implemented \n")
       }
     }
   }else{
+    warning("Crosswalk for the country specified is not implemented \n")
     return(-2)
-    stop("Crosswalk for the country specified is not implemented \n")
   }
-  
 }
-
 ###########################################################################################################
 #' Function to map EQ-5D-5L scores to EQ-5D-3L index values as per the specific country and group by gender and age
 #' @param eq5dresponse.data the data containing eq5d5L responses
@@ -800,8 +811,8 @@ eq5dmap5Lto3L<-function(eq5dresponse.data,mobility, self.care,usual.activities,p
     working.data=subsetGenderAgeToGroup(eq5dresponse.data,groupby,agelimit)
     scores=c()
     if(nrow(working.data)<1){
+      warning("No entries with the given criteria - Please check the contents or the criteria \n")
       return(-2)
-      stop("No entries with the given criteria - Please check the contents or the criteria \n")
     }else{
       for(j in 1:nrow(working.data)){
         res1=working.data[j,mobility]
@@ -813,8 +824,8 @@ eq5dmap5Lto3L<-function(eq5dresponse.data,mobility, self.care,usual.activities,p
         if(this.score!=-1){
           scores=c(scores,this.score)
         }else{
+          warning("EQ-5D-5L responses not valid - 5L scores can not be valued \n")
           return(-3)
-          stop("EQ-5D-5L responses not valid - 5L scores can not be valued \n")
         }
       }
       #names(scores)<-"Mapped EQ-5D-3Lscores"
@@ -845,8 +856,8 @@ eq5dmap5Lto3L<-function(eq5dresponse.data,mobility, self.care,usual.activities,p
       return(results)
     }
   }else{# if the eq 5d column names do not match
+    warning("EQ-5D column names do not match \n")
     return(-1)
-    stop("EQ-5D column names do not match \n")
   }
 }
 ###########################################################################################################
@@ -862,7 +873,6 @@ eq5dmap5Lto3L<-function(eq5dresponse.data,mobility, self.care,usual.activities,p
                                           33232,33323,13332,13333,23332,23333,32333,33332,33333)
   australia.impalusibleordering.values<-c(-0.045, 0.154,0.154, 0.086,0.086,-0.083,-0.083,0.101,0.101,0.033,0.033,-0.136,-0.136,
                                           -0.098,-0.199,0.020,0.020,-0.048,-0.048,-0.206,-0.217,-0.217)
-  
   if(sum(score.num%in%australia.impalusibleordering.scores)>0){
     index<-which(score.num==australia.impalusibleordering.scores)
     value<-australia.impalusibleordering.values[index]
